<?php

// Check if schedule_id is empty and set it to 386 as a fallback
if (empty($_POST['schedule_id'])) {
    $_POST['schedule_id'] = "386"; // JIT Session for REI
}

// Initialize an array to store errors and post parameters
$errors = [];
$post_params = $_POST;

// Retrieve form data using null coalescing operator to avoid undefined index warnings
$name = $_POST['name'] ?? null;
$email = $_POST['email'] ?? null;
$phone = $_POST['phone'] ?? '';
$phone_code = $_POST['phone_code'] ?? '';
$schedule_id = $_POST['schedule_id'] ?? '';
$date = $_POST['date'] ?? '';
$timezone = $_POST['timezone'] ?? '';
$consent = $_POST['consent'] ?? '';

$full_phone = $phone_code . $phone; // Combine phone code and phone number

// Trim whitespace from timezone and handle 'GMT' case
$timezone = str_replace(' ', '', $timezone);
if ($timezone == "GMT") {
    $timezone = "GMT+0";
}

// Validate form inputs
if (!$name) {
    $errors[] = "Name is empty";
} else {
    // Split the name into first name and last name
    $nameparts = explode(" ", $name);
    $firstname = $nameparts[0] ?? '';
    $lastname = $nameparts[1] ?? ''; // Corrected to use null coalescing operator
}

if (!$email) {
    $errors[] = "Email is empty";
}

if ($phone === '') {
    $phone_code = '';
}

// Check for errors and handle logging
if (!empty($errors)) {
    // Log errors
    $error_log = fopen('error_log.txt', 'a');
    fwrite($error_log, "[" . date('Y-m-d H:i:s') . "] " . implode("\n", $errors) . "\n");
    fclose($error_log);
    
    // Output error message to the user
    echo "Error";
    exit;
}

// Define API endpoint and data
$url = 'https://api.webinarjam.com/everwebinar/register';
$data = [
    'api_key' => '8f4af42b-4463-49ac-8e72-e4108dfa6944',
    'webinar_id' => '61',
    'first_name' => $firstname,
    'last_name' => $lastname,
    'email' => $email,
    'phone' => $phone,
    'phone_country_code' => $phone_code,
    'schedule' => $schedule_id,
    'date' => $date,
    'timezone' => $timezone
];

// Prepare HTTP POST request
$options = [
    'http' => [
        'header' => "Content-type: application/x-www-form-urlencoded\r\n",
        'method' => 'POST',
        'content' => http_build_query($data)
    ]
];

$context = stream_context_create($options);
$result = file_get_contents($url, false, $context);

// Check the result of the API call
if ($result === FALSE) {
    // Log failure
    $error_log = fopen('error_log.txt', 'a');
    fwrite($error_log, "[" . date('Y-m-d H:i:s') . "] Failed API call: " . print_r($post_params, true) . "\n");
    fclose($error_log);

    // Output error message to the user
    echo "Error";
    exit;
}

// Decode JSON response
$json = json_decode($result, true);

// Extract necessary data from JSON response
$live_param = $json['user']['live_room_url'] ?? null;
$countdown = $json['user']['date'] ?? null;
$date2 = $json['user']['date'] ?? null;
$timezone2 = $json['user']['timezone'] ?? null;
$schedule2 = $json['user']['schedule'] ?? null;
$dateObj = DateTime::createFromFormat('Y-m-d H:i', $date2);

$formattedDate = $dateObj->format('Y-m-d h:i A');

$redirect_url = "https://www.howtobuycashflow.com/training-waiting-room?tz=" . $timezone2 . "&join=" . $live_param . "&date_print=" . $formattedDate;

  

// Call the Zapier webhook with the response data
$webhook_url = 'https://hooks.zapier.com/hooks/catch/11622204/304vhjm/';
$webhook_data = [
    'first_name' => $firstname,
    'last_name' => $lastname,
    'email' => $email,
    'phone' => $phone,
    'phone_country_code' => $phone_code,
    'schedule' => $schedule2,
    'live_room_url' => $live_param,
    'countdown' => $countdown,
    'date' => $date2,
    'timezone' => $timezone2,
    // Add other fields as needed from the API response
];
$webhook_content = http_build_query($webhook_data);
$webhook_options = [
    'http' => [
        'header' => "Content-type: application/x-www-form-urlencoded\r\n",
        'method' => 'POST',
        'content' => $webhook_content
    ]
];
$webhook_context = stream_context_create($webhook_options);
$webhook_result = file_get_contents($webhook_url, false, $webhook_context);

// Log error if the webhook call failed
if ($webhook_result === FALSE) {
    $error_log = fopen('error_log.txt', 'a');
    fwrite($error_log, "[" . date('Y-m-d H:i:s') . "] Failed webhook call to Zapier: " . print_r($webhook_data, true) . "\n");
    fclose($error_log);
}

// Redirect the user to the training waiting room
header('Location: ' . $redirect_url);

?>
